==> zio-aws-iottwinmaker_2.13-5.17.144.1-sources.jar: zio/aws/iottwinmaker/model/ListComponentTypesResponse.scala <==
package zio.aws.iottwinmaker.model
import java.lang.Integer
import zio.aws.iottwinmaker.model.primitives.{Id, NextToken, MaxResults}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListComponentTypesResponse(
    componentTypeSummaries: Iterable[
      zio.aws.iottwinmaker.model.ComponentTypeSummary
    ],
    maxResults: Option[MaxResults] = None,
    nextToken: Option[NextToken] = None,
    workspaceId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse = {
    import ListComponentTypesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
      .builder()
      .componentTypeSummaries(componentTypeSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .workspaceId(Id.unwrap(workspaceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ListComponentTypesResponse.wrap(buildAwsValue())
}
object ListComponentTypesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ListComponentTypesResponse =
      zio.aws.iottwinmaker.model.ListComponentTypesResponse(
        componentTypeSummaries.map { item =>
          item.asEditable
        },
        maxResults.map(value => value),
        nextToken.map(value => value),
        workspaceId
      )
    def componentTypeSummaries
        : List[zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly]
    def maxResults: Option[MaxResults]
    def nextToken: Option[NextToken]
    def workspaceId: Id
    def getComponentTypeSummaries: ZIO[Any, Nothing, List[
      zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly
    ]] = ZIO.succeed(componentTypeSummaries)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getWorkspaceId: ZIO[Any, Nothing, Id] = ZIO.succeed(workspaceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ) extends zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly {
    override val componentTypeSummaries
        : List[zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly] = impl
      .componentTypeSummaries()
      .asScala
      .map { item =>
        zio.aws.iottwinmaker.model.ComponentTypeSummary.wrap(item)
      }
      .toList
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.iottwinmaker.model.primitives.MaxResults(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iottwinmaker.model.primitives.NextToken(value))
    override val workspaceId: Id =
      zio.aws.iottwinmaker.model.primitives.Id(impl.workspaceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ): zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iottwinmaker_2.13-5.17.295.5-sources.jar: zio/aws/iottwinmaker/model/ListComponentTypesResponse.scala <==
package zio.aws.iottwinmaker.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iottwinmaker.model.primitives.{Id, NextToken, MaxResults}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListComponentTypesResponse(
    componentTypeSummaries: Iterable[
      zio.aws.iottwinmaker.model.ComponentTypeSummary
    ],
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    workspaceId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse = {
    import ListComponentTypesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
      .builder()
      .componentTypeSummaries(componentTypeSummaries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .workspaceId(Id.unwrap(workspaceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ListComponentTypesResponse.wrap(buildAwsValue())
}
object ListComponentTypesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ListComponentTypesResponse =
      zio.aws.iottwinmaker.model.ListComponentTypesResponse(
        componentTypeSummaries.map { item =>
          item.asEditable
        },
        maxResults.map(value => value),
        nextToken.map(value => value),
        workspaceId
      )
    def componentTypeSummaries
        : List[zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly]
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[NextToken]
    def workspaceId: Id
    def getComponentTypeSummaries: ZIO[Any, Nothing, List[
      zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly
    ]] = ZIO.succeed(componentTypeSummaries)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getWorkspaceId: ZIO[Any, Nothing, Id] = ZIO.succeed(workspaceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ) extends zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly {
    override val componentTypeSummaries
        : List[zio.aws.iottwinmaker.model.ComponentTypeSummary.ReadOnly] = impl
      .componentTypeSummaries()
      .asScala
      .map { item =>
        zio.aws.iottwinmaker.model.ComponentTypeSummary.wrap(item)
      }
      .toList
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.iottwinmaker.model.primitives.MaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iottwinmaker.model.primitives.NextToken(value))
    override val workspaceId: Id =
      zio.aws.iottwinmaker.model.primitives.Id(impl.workspaceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListComponentTypesResponse
  ): zio.aws.iottwinmaker.model.ListComponentTypesResponse.ReadOnly =
    new Wrapper(impl)
}
